﻿using System;
using System.Windows.Forms;

namespace GamblerSimulator
{
    internal static class ExtensionMethods
    {
        internal static int GetMoneyValue(this Label label)
        {
            return int.Parse(label.Text);
        }

        internal static void SetMoneyValue(this Label label, int value, int length = 6)
        {
            var valueStr = value.ToString();
            var zeroNeeded = length - valueStr.Length;
            if (zeroNeeded < 0)
            {
                throw new Exception("Value length is too long!");
            }
            var zeros = new string('0', zeroNeeded);
            label.Text = zeros + valueStr;
        }

        internal static int GiveMoney(this Label label, int amount)
        {
            return label.ChangeMoneyValue(oldValue => oldValue + amount);
        }

        internal static int TakeMoney(this Label label, int amount)
        {
            return label.ChangeMoneyValue(oldValue => oldValue - amount);
        }

        private delegate int MoneyTransaction(int oldValue);

        private static int ChangeMoneyValue(this Label label, MoneyTransaction operation)
        {
            var currentValue = label.GetMoneyValue();
            var newValue = operation(currentValue);
            label.SetMoneyValue(newValue);
            return newValue;
        }
    }
}
